Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(113)

Unified Diff: ash/common/wm/system_modal_container_layout_manager.h

Issue 2699033002: Replace WmWindowObserver with aura::WindowObserver. (Closed)
Patch Set: Check for null images in ShelfWindowWatcher. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/wm/root_window_layout_manager.cc ('k') | ash/common/wm/system_modal_container_layout_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/wm/system_modal_container_layout_manager.h
diff --git a/ash/common/wm/system_modal_container_layout_manager.h b/ash/common/wm/system_modal_container_layout_manager.h
index 7bf81c85c77cabdb79da9b819273c9ae0f032a2d..171b0f46d2c98e921b5ccf761eea7627e608d61f 100644
--- a/ash/common/wm/system_modal_container_layout_manager.h
+++ b/ash/common/wm/system_modal_container_layout_manager.h
@@ -11,8 +11,8 @@
#include "ash/ash_export.h"
#include "ash/common/wm/wm_snap_to_pixel_layout_manager.h"
-#include "ash/common/wm_window_observer.h"
#include "base/macros.h"
+#include "ui/aura/window_observer.h"
#include "ui/keyboard/keyboard_controller_observer.h"
namespace gfx {
@@ -27,7 +27,7 @@ class WindowDimmer;
// when the container size changes.
class ASH_EXPORT SystemModalContainerLayoutManager
: public wm::WmSnapToPixelLayoutManager,
- public WmWindowObserver,
+ public aura::WindowObserver,
public keyboard::KeyboardControllerObserver {
public:
explicit SystemModalContainerLayoutManager(WmWindow* container);
@@ -43,9 +43,10 @@ class ASH_EXPORT SystemModalContainerLayoutManager
void SetChildBounds(WmWindow* child,
const gfx::Rect& requested_bounds) override;
- // Overridden from WmWindowObserver:
- void OnWindowPropertyChanged(WmWindow* window,
- WmWindowProperty property) override;
+ // Overridden from aura::WindowObserver:
+ void OnWindowPropertyChanged(aura::Window* window,
+ const void* key,
+ intptr_t old) override;
// Overridden from keyboard::KeyboardControllerObserver:
void OnKeyboardBoundsChanging(const gfx::Rect& new_bounds) override;
« no previous file with comments | « ash/common/wm/root_window_layout_manager.cc ('k') | ash/common/wm/system_modal_container_layout_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698